"use client";

import { useState } from "react";
import { Card } from "@/components/ui/card";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { ScrollArea } from "@/components/ui/scroll-area";
import { MessageCircle, Send } from "lucide-react";

export default function SupportSection() {
  const [message, setMessage] = useState("");
  const [isSending, setIsSending] = useState(false);

  const handleSendMessage = async () => {
    if (!message.trim()) return;
    
    setIsSending(true);
    try {
      // Implement message sending logic here
      setMessage("");
    } catch (error) {
      console.error("Failed to send message:", error);
    } finally {
      setIsSending(false);
    }
  };

  return (
    <Card className="p-6">
      <div className="flex items-center gap-2 mb-6">
        <MessageCircle className="h-5 w-5" />
        <h2 className="text-xl font-semibold">Support Chat</h2>
      </div>

      <ScrollArea className="h-[400px] border rounded-md p-4 mb-4">
        <div className="space-y-4">
          <div className="bg-muted p-3 rounded-lg">
            <p className="text-sm">
              Hello! How can we help you today?
            </p>
            <span className="text-xs text-muted-foreground">
              Support Team • Just now
            </span>
          </div>
        </div>
      </ScrollArea>

      <div className="flex gap-2">
        <Input
          value={message}
          onChange={(e) => setMessage(e.target.value)}
          placeholder="Type your message..."
          onKeyPress={(e) => e.key === "Enter" && handleSendMessage()}
        />
        <Button
          onClick={handleSendMessage}
          disabled={isSending || !message.trim()}
        >
          <Send className="h-4 w-4" />
        </Button>
      </div>

      <div className="mt-4 text-xs text-muted-foreground text-center">
        Average response time: 5 minutes
      </div>
    </Card>
  );
}